ase-gui — ASE documentation

### Navigation

- index
- modules |
- Documentation for modules in ASE »

# ase-gui

The graphical user-interface allows users to visualize, manipulate, and render molecular systems and atoms objects. It also allows to setup and run a number of calculations and can be used to transfer between different file formats.

- ase-gui basics and command line options
  - General use
  - Files
  - Selecting part of a trajectory
  - Writing files
  - Interactive use
  - NEB calculations
  - Plotting data from the command line
  - Defaults for ase-gui
  - High contrast settings for ase-gui
- Edit
  - Add atoms
  - Modify
  - Copy/Paste
- View
  - Repeat
  - Rotate
  - Colors
  - Settings
- Tools
  - Graphs
  - Movie
  - Expert mode
  - Constraints
  - Render scene
  - Move atoms
  - Rotate atoms
  - Orient atoms
  - NEB
  - Bulk Modulus
- Setup
- Calculate
  - Set calculator
  - Energy and forces
  - Energy minimization
  - Scale system

### Navigation

- index
- modules |
- Documentation for modules in ASE »